import "./tasks/fastp.wdl" as fastp
import "./tasks/hisat2.wdl" as hisat2
import "./tasks/samtools.wdl" as samtools
import "./tasks/featureCounts.wdl" as featureCounts


workflow {{ project_name }} {
    String sample_id
    File read1
    File read2
    String adapter_sequence
    String adapter_sequence_r2
    String fastp_docker
    String fastp_cluster
    String umi_loc	
    Int trim_front1
    Int trim_tail1
    Int max_len1
    Int trim_front2
    Int trim_tail2
    Int max_len2
    Int disable_adapter_trimming
    Int length_required
    Int umi_len
    Int UMI
    Int qualified_quality_phred
    Int length_required1
    Int disable_quality_filtering
    File idx
    String idx_prefix
    String pen_intronlen
    String hisat2_docker
    String hisat2_cluster	
    Int pen_cansplice
    Int pen_noncansplice
    Int min_intronlen
    Int max_intronlen
    Int maxins
    Int minins	
    String ins_size = sample_id + ".ins_size"
    String samtools_docker
    String samtools_cluster	
    Int insert_size	
    File lnc_gtf_file
    String subread_docker
    String subread_cluster	

	call fastp.fastp as fastp {
		input: 
		sample_id = sample_id,
		read1 = read1, 
		read2 = read2,
		docker = fastp_docker,
		cluster = fastp_cluster,
		adapter_sequence = adapter_sequence,
		adapter_sequence_r2 = adapter_sequence_r2,
		umi_loc = umi_loc,
		trim_front1 = trim_front1,
		trim_tail1 = trim_tail1, 
		max_len1 = max_len1,
		trim_front2 = trim_front2,
		trim_tail2 = trim_tail2,
		max_len2 = max_len2,
		disable_adapter_trimming = disable_adapter_trimming,
		length_required = length_required,
		umi_len = umi_len,
		UMI = UMI,
		qualified_quality_phred = qualified_quality_phred,
		length_required1 = length_required1,
		disable_quality_filtering = disable_quality_filtering
	}

	call hisat2.hisat2 as hisat2 {
		input: 
		sample_id = sample_id,
		idx = idx, 
		idx_prefix = idx_prefix, 
		Trim_R1 = fastp.Trim_R1, 
		Trim_R2 = fastp.Trim_R2,
		docker = hisat2_docker,
		cluster = hisat2_cluster,
		pen_intronlen = pen_intronlen,
		pen_cansplice = pen_cansplice,
		pen_noncansplice = pen_noncansplice,
		min_intronlen = min_intronlen,
		max_intronlen = max_intronlen,
		maxins = maxins,
		minins = minins
	}

	call samtools.samtools as samtools {
		input: 
		sample_id = sample_id,
		sam = hisat2.sam,
		docker = samtools_docker,
		cluster = samtools_cluster,
		insert_size = insert_size
	}

	call featureCounts.featureCounts as featureCounts {
		input: 
		sample_id = sample_id,
		bam_file = samtools.out_bam,
		lnc_gtf_file = lnc_gtf_file,
		docker = subread_docker,
		cluster = subread_cluster
	}
}